"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logError = void 0;
var console_utils_1 = require("./console.utils");
var stderr = console.error.bind(console);
function logError(err) {
    /* eslint-disable-next-line @typescript-eslint/ban-ts-comment */
    // @ts-ignore
    var error = err.error || err;
    var errorName = error.name ? "".concat(error.name, " ") : '';
    var errorMessage = error.message || error;
    var description = errorName ? "".concat(errorName, " ").concat(errorMessage) : errorMessage;
    var message = normalizeErrorMessage(error, description);
    (0, console_utils_1.space)();
    stderr(console_utils_1.color.error(message));
    if (error.loc) {
        stderr("at ".concat(error.loc.file, ":").concat(error.loc.line, ":").concat(error.loc.column));
    }
    (0, console_utils_1.space)();
    if (error.frame) {
        stderr(console_utils_1.color.error(error.frame));
    }
    else if (err.stack) {
        var headlessStack = error.stack.replace(message, '');
        stderr(console_utils_1.color.error(headlessStack));
    }
    (0, console_utils_1.space)();
}
exports.logError = logError;
function normalizeErrorMessage(error, description) {
    if (!error.plugin) {
        return description;
    }
    return error.plugin === 'rpt2' ? "(typescript) ".concat(description) : "(".concat(error.plugin, " plugin) ").concat(description);
}
